@@ -35,9 +35,19 @@ extern const char *CJOSE_HDR_CTY;
 /** The Jose "kid" header attribute. */
 extern const char *CJOSE_HDR_KID;
 
+/** The Jose "epk" header attribte. */
+extern const char *CJOSE_HDR_EPK;
+
+/** For ECDH-ES algorithms, the PartyU and PartyV values */
+extern const char *CJOSE_HDR_APU;
+extern const char *CJOSE_HDR_APV;
+
 /** The JWA algorithm attribute value for none. */
 extern const char *CJOSE_HDR_ALG_NONE;
 
+/** The JWE algorithm attribute value of ECDH-ES. */
+extern const char *CJOSE_HDR_ALG_ECDH_ES;
+
 /** The JWE algorithm attribute value for RSA-OAEP. */
 extern const char *CJOSE_HDR_ALG_RSA_OAEP;
 
@@ -72,7 +82,9 @@ extern const char *CJOSE_HDR_ALG_ES512;
 /** The JWE algorithm attribute value for "dir". */
 extern const char *CJOSE_HDR_ALG_DIR;
 
-/** The JWE content encryption algorithm value for A256GCM. */
+/** The JWE content encryption algorithm value for A128GCM, A192GCM and A256GCM. */
+extern const char *CJOSE_HDR_ENC_A128GCM;
+extern const char *CJOSE_HDR_ENC_A192GCM;
 extern const char *CJOSE_HDR_ENC_A256GCM;
 
 /** The JWE content encryption algorithm value for A128CBC-HS256, A192CBC-HS384 and A256CBC-HS512. */
@@ -100,7 +112,7 @@ cjose_header_t *cjose_header_new(cjose_err *err);
  * header will be used past the scope it was created in (e.g., from a
  * `cjose_jws_t` object).
  *
- * \param header[in] the header object to be retained.
+ * \param header [in] the header object to be retained.
  * \returns the retained header object
  */
 cjose_header_t *cjose_header_retain(cjose_header_t *header);
@@ -110,7 +122,7 @@ cjose_header_t *cjose_header_retain(cjose_header_t *header);
  * to dispose of header rather than directly free'ing a cjose_header
  * object.
  *
- * \param header[in] the header object to be released.
+ * \param header [in] the header object to be released.
  */
 void cjose_header_release(cjose_header_t *header);
 
@@ -118,9 +130,9 @@ void cjose_header_release(cjose_header_t *header);
  * Sets a header attribute on a header object.  If that header was
  * previously set, this will replace the previous value with the new one.
  *
- * \param header[in] a previously instantated header object.
- * \param attr[in] the header attribute to be set.
- * \param value[in] the value to assign to the header attribute.
+ * \param header [in] a previously instantiated header object.
+ * \param attr [in] the header attribute to be set.
+ * \param value [in] the value to assign to the header attribute.
  * \param err [out] An optional error object which can be used to get additional
  *        information in the event of an error.
  * \returns true if header is successfully set.
@@ -131,18 +143,42 @@ bool cjose_header_set(cjose_header_t *header, const char *attr, const char *valu
  * Retrieves the value of the requested header attribute from the header
  * object.
  *
- * \param header[in] a header object.
- * \param attr[in] the header attribute to be got.
+ * \param header [in] a header object.
+ * \param attr [in] the header attribute to be got.
  * \param err [out] An optional error object which can be used to get additional
  *        information in the event of an error.
  * \returns a string containing the current value for the requested attribute.
  * The value returned is a null terminated UTF-8 encoded string, or NULL if corresponding
- * string header was not found. The retuned value is read-only and must not be modified
+ * string header was not found. The returned value is read-only and must not be modified
  * or freed by the user. It is valid as long as the corresponding cjose_header_t object
  * is not released.
  */
 const char *cjose_header_get(cjose_header_t *header, const char *attr, cjose_err *err);
 
+/**
+ * Sets a raw header attribute on a header object. If that header was
+ * previously set, this will replace the previous value with the new one.
+ * The input value must be a JSON serialized string. This function does not
+ * retain pointers to specified attribute or value.
+ *
+ * \param header [in] a previously instantiated header object.
+ * \param attr [in] the header attribute to be set.
+ * \param value [in] the JSON value to assign to the header attribute. The value must
+ * be a valid JSON, and will be assigned as is.
+ */
+bool cjose_header_set_raw(cjose_header_t *header, const char *attr, const char *value, cjose_err *err);
+
+/**
+ * Retrieves the raw value of the requested header attribute from the header
+ * object.
+ * \param header [in] a header object.
+ * \param attr [in] the header attribute to be got.
+ * \param err [out] An optional error object which can be used to get additional
+ *        information in the event of an error.
+ * \returns a string containing the current JSON value for the requested attribute.
+ */
+char *cjose_header_get_raw(cjose_header_t *header, const char *attr, cjose_err *err);
+
 #ifdef __cplusplus
 }
 #endif
